@@ -223,17 +223,18 @@ class RichOptionPanel(RichPanel[Parameter, OptionColumnType]):
 
             rows.append(cols)
 
-        if True:
-            rows = list(
-                map(
-                    list,
-                    zip(*[col for col in zip(*rows) if any(cell for cell in col)]),
-                )
-            )
+        headers = [i.replace("_", " ").title() for i in formatter.config.options_table_column_types]
+
+        filtered = [(h, c) for h, c in zip(headers, zip(*rows)) if any(cell for cell in c)]
+        headers, rows = zip(*filtered) if filtered else ([], [])
+        rows = list(map(list, zip(*rows))) if rows else []
 
         for row in rows:
             table.add_row(*row)
 
+        for col, header in zip(table.columns, headers):
+            col.header = header
+
         return table
 
     def render(
@@ -314,8 +315,12 @@ class RichCommandPanel(RichPanel[Command, CommandColumnType]):
     def list_all_objects(cls, ctx: Context) -> List[Tuple[str, Command]]:
         if not isinstance(ctx.command, Group):
             return []
-
-        return list(sorted(list(ctx.command.commands.items())))
+        commands = []
+        for cmd_name in ctx.command.list_commands(ctx):
+            cmd = ctx.command.get_command(ctx, cmd_name)
+            if cmd is not None:
+                commands.append((cmd_name, cmd))
+        return commands
 
     def get_objects(self, command: Command, ctx: Context) -> Generator[Command, None, None]:
         """List the objects assigned to the panel."""
@@ -386,17 +391,18 @@ class RichCommandPanel(RichPanel[Command, CommandColumnType]):
 
             rows.append(cols)
 
-        if True:
-            rows = list(
-                map(
-                    list,
-                    zip(*[col for col in zip(*rows) if any(cell for cell in col)]),
-                )
-            )
+        headers = [i.replace("_", " ").title() for i in formatter.config.commands_table_column_types]
+
+        filtered = [(h, c) for h, c in zip(headers, zip(*rows)) if any(cell for cell in c)]
+        headers, rows = zip(*filtered) if filtered else ([], [])
+        rows = list(map(list, zip(*rows))) if rows else []
 
         for row in rows:
             table.add_row(*row)
 
+        for col, header in zip(table.columns, headers):
+            col.header = header
+
         return table
 
     def render(
